/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                                 v 7.0                    *
*********************************************************************************
* Id: fxplayer_opts.h,                                 2008/01/01               *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, see <http://www.gnu.org/licenses/>           *
********************************************************************************/

           /* *******************************************************************
            * Acknowledgements:                                                 *
            * the code written in this file is based on Various                 * 
            * utilities for command line tools & part of FFmpeg                 *
            * Copyright (c) 2003 Fabrice Bellard,                               *
            *                                                                   *
            * FFmpeg is free software; you can redistribute it and/or           *
            * modify it under the terms of the GNU Lesser General Public        *
            * License as published by the Free Software Foundation; either      *
            * version 2.1 of the License, or (at your option) any later version.*
            ******************************************************************* */

#ifndef FXPLAYER_OPTS_H
#define FXPLAYER_OPTS_H

#include "config.h"

#ifdef ENABLE_PLAYERS

#ifdef HAVE_LIBAVCODEC
 #include <libavcodec/avcodec.h>
#endif
#ifdef HAVE_LIBAVFILTER
 #include <libavfilter/avfilter.h>
#endif
#ifdef HAVE_LIBAVFORMAT
 #include <libavformat/avformat.h>
#endif
#ifdef HAVE_LIBSWSCALE
 #include <libswscale/swscale.h>
#endif

//#include <libavutil/mem.h>

extern struct SwsContext *sws_opts;
extern AVDictionary *swr_opts;
extern AVDictionary *sws_dict;
extern AVDictionary *format_opts, *codec_opts, *resample_opts;

void init_opts();

void uninit_opts();


/**
 * Check if the given stream matches a stream specifier.
 *
 * @param s  Corresponding format context.
 * @param st Stream from s to be checked.
 * @param spec A stream specifier of the [v|a|s|d]:[\<stream index\>] form.
 *
 * @return 1 if the stream matches, 0 if it doesn't, <0 on error
 */
int check_stream_specifier(AVFormatContext *s, AVStream *st, const char *spec);


/**
 * Filter out options for given codec.
 *
 * Create a new options dictionary containing only the options from
 * opts which apply to the codec with ID codec_id.
 *
 * @param opts     dictionary to place options in
 * @param codec_id ID of the codec that should be filtered for
 * @param s Corresponding format context.
 * @param st A stream from s for which the options should be filtered.
 * @param codec The particular codec for which the options should be filtered.
 *              If null, the default one is looked up according to the codec id.
 * @return a pointer to the created dictionary
 */
AVDictionary *filter_codec_opts(AVDictionary *opts, enum AVCodecID codec_id,
                                AVFormatContext *s, AVStream *st, AVCodec *codec);

/**
 * Setup AVCodecContext options for avformat_find_stream_info().
 *
 * Create an array of dictionaries, one dictionary for each stream
 * contained in s.
 * Each dictionary will contain the options from codec_opts which can
 * be applied to the corresponding stream codec context.
 *
 * @return pointer to the created array of dictionaries, NULL if it
 * cannot be created
 */
AVDictionary **setup_find_stream_info_opts(AVFormatContext *s,
                                           AVDictionary *codec_opts);

/**
 * Wraps exit with a program-specific cleanup routine.
 */
void exit_program(int ret) av_noreturn;

/**
 * Register a program-specific cleanup routine.
 */
void register_exit(void (*cb)(int ret));

/**
 * Initialize dynamic library loading
 */
void init_dynload(void);


/**
 * Realloc array to hold new_size elements of elem_size.
 * Calls exit() on failure.
 *
 * @param array array to reallocate
 * @param elem_size size in bytes of each element
 * @param size new element count will be written here
 * @param new_size number of elements to place in reallocated array
 * @return reallocated array
 */
void *grow_array(void *array, int elem_size, int *size, int new_size);

#define GROW_ARRAY(array, nb_elems)\
    array = grow_array(array, sizeof(*array), &nb_elems, nb_elems + 1)

double get_rotation(AVStream *st);

/**
 * Print an error message to stderr, indicating filename and a human
 * readable description of the error code err.
 *
 * If strerror_r() is not available the use of this function in a
 * multithreaded application may be unsafe.
 *
 * @see av_strerror()
 */
void print_error(const char *filename, int err);


#endif /* ENABLE_PLAYER */

#endif /* FXPLAYER_OPTS_H */

