/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2018 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                                 v 7.0                    *
*********************************************************************************
* Id: fxplayer_utils.c,                                2008/01/01               *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, see <http://www.gnu.org/licenses/>           *
********************************************************************************/

#include "fxplayer_utils.h"

#ifdef ENABLE_PLAYERS

float screen_increment_conversion(float increment_size, int increment_step){
    // set the screen size factor according to GUI command
    switch (increment_step) { 
      case -3:
        increment_size = 0.6;
        break;
      case -2:
        increment_size = 0.8;
        break;
      case -1:
        increment_size = 0.9;
        break;
      case 0: 
        increment_size = 1.0; // original size
        break;
      case 1:
        increment_size = 1.3;
        break;
      case 2:
        increment_size = 1.6;
        break;
      case 3:
        increment_size = 1.9;
        break;
      case 4:
        increment_size = 2.2;
        break;
      case 5:
        increment_size = 2.5;
        break;
      case 6:
        increment_size = 2.8;
        break;
      case 7:
        increment_size = 3.1;
        break;
      case 8:
        increment_size = 3.4;
        break;
    }
    return increment_size;
}


int video_screen_resize(int s, int enlarge_s){
    // manually change the aspect ratio of the picture
    switch (enlarge_s) { 
      case 0: // original size
        break;
      case 1:
        s = s + s*0.1;
        break;
      case 2:
        s = s + s*0.2;
        break;
      case 3:
        s = s + s*0.3;
        break;
      case 4:
        s = s + s*0.4;
        break;
      case 5:
        s = s + s*0.5;
        break;
      case 6:
        s = s + s*0.6;
        break;
      case 7:
        s = s + s*0.7;
        break;
      case 8:
        s = s + s*0.8;
        break;
      case 9:
        s = s + s*0.9; // max size
        break;
      case -1:
        s = s - s*0.1;
        break;
      case -2:
        s = s - s*0.2;
        break;
      case -3:
        s = s - s*0.3;
        break;
      case -4:
        s = s - s*0.4;
        break;
      case -5:
        s = s - s*0.5;
        break;
      case -6:
        s = s - s*0.6;
        break;
      case -7:
        s = s - s*0.7;
        break;
      case -8:
        s = s - s*0.8;
        break;
      case -9:
        s = s - s*0.9; // min size
        break;
    }
    return s;
}

char set_volume_icon(int volume){

    switch (volume) { 
    case 100:
    case 99:
    case 98:
    case 97:
    case 96:
        imgcmd_10 = ICON_9;
        imgcmd_01 = ICON_9;
        break;
    case 95:
    case 94:
    case 93:
    case 92:
    case 91:
        imgcmd_10 = ICON_9;
        imgcmd_01 = ICON_5;
        break;
    case 90:
    case 89:
    case 88:
    case 87:
    case 86:
        imgcmd_10 = ICON_9;
        imgcmd_01 = ICON_0;
        break;
    case 85:
    case 84:
    case 83:
    case 82:
    case 81:
        imgcmd_10 = ICON_8;
        imgcmd_01 = ICON_5;
        break;
    case 80:
    case 79:
    case 78:
    case 77:
    case 76:
        imgcmd_10 = ICON_8;
        imgcmd_01 = ICON_0;
        break;
    case 75:
    case 74:
    case 73:
    case 72:
    case 71:
        imgcmd_10 = ICON_7;
        imgcmd_01 = ICON_5;
        break;
    case 70:
    case 69:
    case 68:
    case 67:
    case 66:
        imgcmd_10 = ICON_7;
        imgcmd_01 = ICON_0;
        break;
    case 65:
    case 64:
    case 63:
    case 62:
    case 61:
        imgcmd_10 = ICON_6;
        imgcmd_01 = ICON_5;
        break;
    case 60:
    case 59:
    case 58:
    case 57:
    case 56:
        imgcmd_10 = ICON_6;
        imgcmd_01 = ICON_0;
        break;
    case 55:
    case 54:
    case 53:
    case 52:
    case 51:
        imgcmd_10 = ICON_5;
        imgcmd_01 = ICON_5;
        break;
    case 50:
    case 49:
    case 48:
    case 47:
    case 46:
        imgcmd_10 = ICON_5;
        imgcmd_01 = ICON_0;
        break;
    case 45:
    case 44:
    case 43:
    case 42:
    case 41:
        imgcmd_10 = ICON_4;
        imgcmd_01 = ICON_5;
        break;
    case 40:
    case 39:
    case 38:
    case 37:
    case 36:
        imgcmd_10 = ICON_4;
        imgcmd_01 = ICON_0;
        break;
    case 35:
    case 34:
    case 33:
    case 32:
    case 31:
        imgcmd_10 = ICON_3;
        imgcmd_01 = ICON_5;
        break;
    case 30:
    case 29:
    case 28:
    case 27:
    case 26:
        imgcmd_10 = ICON_3;
        imgcmd_01 = ICON_0;
        break;
    case 25:
    case 24:
    case 23:
    case 22:
    case 21:
        imgcmd_10 = ICON_2;
        imgcmd_01 = ICON_5;
        break;
    case 20:
    case 19:
    case 18:
    case 17:
    case 16:
        imgcmd_10 = ICON_2;
        imgcmd_01 = ICON_0;
        break;
    case 15:
    case 14:
    case 13:
    case 12:
    case 11:
        imgcmd_10 = ICON_1;
        imgcmd_01 = ICON_5;
        break;
    case 10:
    case 9:
    case 8:
    case 7:
    case 6:
        imgcmd_10 = ICON_1;
        imgcmd_01 = ICON_0;
        break;
    case 5:
    case 4:
    case 3:
    case 2:
    case 1:
        imgcmd_10 = ICON_0;
        imgcmd_01 = ICON_5;
        break;
    case 0:
        imgcmd_10 = ICON_0;
        imgcmd_01 = ICON_0;
        break;
      default:
        break;
    }
}



#endif /* ENABLE_PLAYERS */
